=======
Authors
=======

* Dario d'Andrea, dariod@playtika.com
* Jerome Carayol, jeromec@playtika.com
* Stefano Piazza, stefanop@playtika.com
* Raphael Steinmann, raphaels@playtika.com
* Armand Valsesia, armandv@playtika.com
